@@ -185,6 +185,9 @@ __published:    // IDE-managed Components
     TMenuItem *M_View_PBCore2;
     TMenuItem *M_View_EBUCore_1_5;
     TMenuItem *M_View_EBUCore_1_6;
+    TMenuItem *M_View_FIMS_1_1;
+    TMenuItem *M_View_FIMS_1_2;
+    TMenuItem *M_View_FIMS_1_3;
     TMenuItem *M_Tektronix;
     TToolButton *Tool_Tektronix;
     TMenuItem *M_View_reVTMD;
@@ -194,6 +197,9 @@ __published:    // IDE-managed Components
     TMenuItem *ToolBar_View_PBCore2;
     TMenuItem *ToolBar_View_EBUCore_1_5;
     TMenuItem *ToolBar_View_EBUCore_1_6;
+    TMenuItem *ToolBar_View_FIMS_1_1;
+    TMenuItem *ToolBar_View_FIMS_1_2;
+    TMenuItem *ToolBar_View_FIMS_1_3;
     TMenuItem *ToolBar_View_reVTMD;
     void __fastcall FormResize(TObject *Sender);
     void __fastcall M_Help_AboutClick(TObject *Sender);
@@ -253,6 +259,9 @@ __published:    // IDE-managed Components
     void __fastcall M_View_PBCore2Click(TObject *Sender);
     void __fastcall M_View_EBUCore_1_5Click(TObject *Sender);
     void __fastcall M_View_EBUCore_1_6Click(TObject *Sender);
+    void __fastcall M_View_FIMS_1_1Click(TObject *Sender);
+    void __fastcall M_View_FIMS_1_2Click(TObject *Sender);
+    void __fastcall M_View_FIMS_1_3Click(TObject *Sender);
     void __fastcall M_View_XMLClick(TObject *Sender);
     void __fastcall M_TektronixClick(TObject *Sender);
     void __fastcall M_View_reVTMDClick(TObject *Sender);
